@@ -1,12 +1,12 @@
 #' Setup environment variables for Slack API access
 #'
-#' Initialize all the environment variables \code{\link{slackr}} will need to use to
+#' Initialize all the environment variables [slackr()] will need to use to
 #' work properly.
 #'
-#' By default, \code{\link{slackr}} (and other functions) will use the \code{#general}
-#' room and a username of \code{slackr()} with no emoji.
+#' By default, [slackr()] (and other functions) will use the `#general`
+#' room and a username of `slackr()` with no emoji.
 #'
-#' If a valid file is found at the locaiton pointed to by \code{config_file}, the
+#' If a valid file is found at the locaiton pointed to by `config_file`, the
 #' values there will be used. The fields should be specified as such in the file:
 #'
 #' \preformatted{
@@ -16,21 +16,23 @@
 #'  incoming_webhook_url: https://hooks.slack.com/services/XXXXX/XXXXX/XXXXX
 #' }
 #'
-#' @param channel default channel to send the output to (chr) defaults to \code{#general}
-#' @param username the username output will appear from (chr) defaults to \code{slackr}
+#' @param channel default channel to send the output to (chr) defaults to `#general`
+#' @param username the username output will appear from (chr) defaults to `slackr`
 #' @param icon_emoji which emoji picture to use (chr) defaults to none (can be
 #'        left blank in config file as well)
 #' @param incoming_webhook_url the Slack URL prefix to use (chr) defaults to none
 #' @param bot_user_oauth_token the Slack full bot user OAuth token (chr)
-#' @param config_file a configuration file (DCF) - see \link{read.dcf} - format
+#' @param config_file a configuration file (DCF) - see [read.dcf] - format
 #'        with the config values.
-#' @param echo display the configuration variables (bool) initially \code{FALSE}
-#' @param cacheChannels a boolean for whether or not you want to cache channels to limit API requests
-#' @note You need a \href{https://slack.com}{Slack} account and all your API URLs & tokens setup
+#' @param echo display the configuration variables (bool) initially `FALSE`
+#' @param cacheChannels a boolean for whether or not you want to cache channels to limit API requests (deprecated)
+#' @param cache_dir the location for an on-disk cache. defaults to an in-memory cache if no location is specified
+#' @importFrom jsonlite toJSON
+#' @return "Successfully connected to Slack"
+#' @note You need a [Slack](https://slack.com) account and all your API URLs & tokens setup
 #'       to use this package.
-#' @seealso \code{\link{slackr}}, \code{\link{dev_slackr}}, \code{\link{save_slackr}},
-#'          \code{\link{slackr_upload}}
-#' @rdname slackr_setup
+#' @seealso [slackr()], [dev_slackr()], [save_slackr()],
+#'          [slackr_upload()]
 #' @examples
 #' \dontrun{
 #' # reads from default file (i.e. ~/.slackr)
@@ -51,13 +53,22 @@ slackr_setup <- function(channel="#general",
                          bot_user_oauth_token="",
                          config_file="~/.slackr",
                          echo=FALSE,
-                         cacheChannels = TRUE) {
+                         cacheChannels = TRUE,
+                         cache_dir = '') {
+
+  if (!missing(cacheChannels)) {
+    warning('cacheChannels parameter is deprecated as of slackr 2.1.0. channels are now auto-cached with memoization')
+  }
+
+  Sys.setenv(SLACK_CACHE_DIR = cache_dir)
 
   if (file.exists(config_file)) {
 
-    config <- read.dcf(config_file,
-                       fields=c("channel", "icon_emoji",
-                                "username", "incoming_webhook_url", "bot_user_oauth_token"))
+    config <- read.dcf(
+      config_file,
+      fields=c("channel", "icon_emoji",
+               "username", "incoming_webhook_url", "bot_user_oauth_token")
+      )
 
     Sys.setenv(SLACK_CHANNEL=config[,"channel"])
     Sys.setenv(SLACK_USERNAME=config[,"username"])
@@ -66,7 +77,9 @@ slackr_setup <- function(channel="#general",
     Sys.setenv(SLACK_BOT_USER_OAUTH_TOKEN=config[,"bot_user_oauth_token"])
 
   } else {
-
+    if (bot_user_oauth_token == '') {
+      stop("No config file found. Please specify your Slack bot OAuth token\n   with the bot_user_oauth_token argument in slackr_setup().")
+    }
     Sys.setenv(SLACK_CHANNEL=channel)
     Sys.setenv(SLACK_USERNAME=username)
     Sys.setenv(SLACK_ICON_EMOJI=icon_emoji)
@@ -88,15 +101,14 @@ slackr_setup <- function(channel="#general",
   }
 
   if (echo) {
-    print(toJSON(as.list(Sys.getenv(c("SLACK_CHANNEL", "SLACK_USERNAME",
-                                      "SLACK_ICON_EMOJI",
-                                      "SLACK_INCOMING_URL_PREFIX", "SLACK_BOT_USER_OAUTH_TOKEN"))),
-                 pretty=TRUE))
+    print(toJSON(as.list(
+      Sys.getenv(c("SLACK_CHANNEL", "SLACK_USERNAME",
+                   "SLACK_ICON_EMOJI",
+                   "SLACK_INCOMING_URL_PREFIX", "SLACK_BOT_USER_OAUTH_TOKEN")
+      )),
+      pretty=TRUE))
   }
 
-  if (cacheChannels) {
-    slackr_createcache(Sys.getenv("SLACK_BOT_USER_OAUTH_TOKEN"))
-  } else if (file.exists('.channel_cache')) {
-    unlink('.channel_cache')
-  }
+  msg <- 'Successfully connected to Slack'
+  return(msg)
 }
